@@ -1,7 +1,7 @@
 import click
 
-from lib.main import Supervisor
-from lib.config import Config
+from .lib.main import Supervisor
+from .lib.config import Config
 
 # To keep things simple, each option here simply
 # modifies a particular configuration value
@@ -53,4 +53,5 @@ def cli(conf, recursive, log, pass_argument):
 ##########
 
 if __name__ == '__main__':
+	print("MAIN")
 	cli()
\ No newline at end of file
